CREATE TABLE departamento (
  cod_departamento INTEGER NOT NULL AUTO_INCREMENT,
  nome_dep VARCHAR(50) NOT NULL,
  descricao TEXT NULL,
  PRIMARY KEY(cod_departamento)
)
TYPE=InnoDB;

CREATE TABLE usuarios (
  cod_usuario INTEGER NOT NULL AUTO_INCREMENT,
  nome_user VARCHAR(50) NOT NULL,
  descricao TEXT NULL,
  PRIMARY KEY(cod_usuario)
)
TYPE=InnoDB;

CREATE TABLE produtos (
  cod_produto INTEGER NOT NULL AUTO_INCREMENT,
  cod_departamento INTEGER NOT NULL,
  nome_produto VARCHAR(50) NOT NULL,
  estoque INTEGER NOT NULL,
  estoque_minimo INTEGER NULL,
  PRIMARY KEY(cod_produto),
  INDEX departamento_FK5(cod_departamento),
  FOREIGN KEY(cod_departamento)
    REFERENCES departamento(cod_departamento)
      ON DELETE RESTRICT
      ON UPDATE RESTRICT
)
TYPE=InnoDB;

CREATE TABLE empresa (
  cod_empresa INTEGER NOT NULL AUTO_INCREMENT,
  cod_departamento INTEGER NOT NULL,
  nome_empresa VARCHAR(50) NULL,
  cnpj CHAR(18) NULL,
  endereco VARCHAR(50) NULL,
  fone VARCHAR(15) NULL,
  atendente VARCHAR(50) NULL,
  email VARCHAR(50) NULL,
  PRIMARY KEY(cod_empresa),
  INDEX empresa_FK4(cod_departamento),
  FOREIGN KEY(cod_departamento)
    REFERENCES departamento(cod_departamento)
      ON DELETE RESTRICT
      ON UPDATE RESTRICT
)
TYPE=InnoDB;

CREATE TABLE compras (
  cod_compra INTEGER NOT NULL AUTO_INCREMENT,
  cod_usuario INTEGER NOT NULL,
  cod_produto INTEGER NOT NULL,
  cod_empresa INTEGER NOT NULL,
  quantidade INTEGER NOT NULL,
  valor_unit DECIMAL(5,2) NOT NULL,
  valor_tot DECIMAL(5,2) NOT NULL,
  nota_fiscal BIGINT NULL,
  data_hora TIMESTAMP NOT NULL,
  situacao CHAR(10) NOT NULL,
  vencimento DATE NOT NULL,
  PRIMARY KEY(cod_compra),
  INDEX empresa_FK1(cod_empresa),
  INDEX produto_FK2(cod_produto),
  INDEX compras_FK3(cod_usuario),
  FOREIGN KEY(cod_empresa)
    REFERENCES empresa(cod_empresa)
      ON DELETE RESTRICT
      ON UPDATE RESTRICT,
  FOREIGN KEY(cod_produto)
    REFERENCES produtos(cod_produto)
      ON DELETE RESTRICT
      ON UPDATE RESTRICT,
  FOREIGN KEY(cod_usuario)
    REFERENCES usuarios(cod_usuario)
      ON DELETE RESTRICT
      ON UPDATE RESTRICT
)
TYPE=InnoDB;

CREATE TABLE pesquisas (
  cod_pesquisa INTEGER NOT NULL AUTO_INCREMENT,
  cod_usuario INTEGER NOT NULL,
  cod_produto INTEGER NOT NULL,
  cod_empresa INTEGER NOT NULL,
  quantidade INTEGER NOT NULL,
  valor_unit DECIMAL(5,2) NOT NULL,
  valor_tot DECIMAL(5,2) NOT NULL,
  data_hora TIMESTAMP NOT NULL,
  PRIMARY KEY(cod_pesquisa),
  INDEX empresa_FK6(cod_empresa),
  INDEX pesquisas_FK7(cod_produto),
  INDEX pesquisas_FK8(cod_usuario),
  FOREIGN KEY(cod_empresa)
    REFERENCES empresa(cod_empresa)
      ON DELETE RESTRICT
      ON UPDATE RESTRICT,
  FOREIGN KEY(cod_produto)
    REFERENCES produtos(cod_produto)
      ON DELETE RESTRICT
      ON UPDATE RESTRICT,
  FOREIGN KEY(cod_usuario)
    REFERENCES usuarios(cod_usuario)
      ON DELETE RESTRICT
      ON UPDATE RESTRICT
)
TYPE=InnoDB;

DELIMITER |
create trigger tu_compras after update on compras
 for each row begin
  update produtos
  set estoque = (estoque - old.quantidade) + new.quantidade
  where cod_produto = new.cod_produto;
 end ;
|
DELIMITER ;

DELIMITER |
create trigger ti_compras after insert on compras
 for each row begin
 update produtos
 set estoque = estoque + new.quantidade
 where cod_produto = new.cod_produto;
end ;
|
DELIMITER ;

DELIMITER |
create trigger td_compras after delete on compras
 for each row begin
  update produtos
  set estoque = estoque - old.quantidade
  where cod_produto = old.cod_produto;
 end ;
|
DELIMITER ;
